
SpamViewModel = class(ViewModelBase);

-- Initializes a new SpamViewModel instance
function SpamViewModel:Constructor(filterEngine)
	ViewModelBase.Constructor(self);

	-- private
	self.Engine = filterEngine;
	self.Policy = self.Engine:GetPolicy("SpamPolicy");
	
	-- public
	self.Title = "Spam Policy";
	self.AutoRefresh = true;
	
	self.NoSpamWordsTable = {};
	self.IsSpamWordsTable = {};
	
	self.NumNoSpamWords = 0;
	self.NumIsSpamWords = 0;
	
	self.NumNoSpamWordEntries = 0;
	self.NumIsSpamWordEntries = 0;

	-- update tables so that we have some data on start up
	self:UpdateTables();

	self.ResetNoSpamCommand = function()
		self.Policy:ResetNoSpam();
		self:UpdateNoSpamWordsTable();
	end;
	
	self.ResetIsSpamCommand = function()
		self.Policy:ResetIsSpam();
		self:UpdateIsSpamWordsTable();
	end;

	self:AddCallback(self.Engine, "MessageCompleted", function()
		self:UpdateTables();
	end);
	
	self:AddCallback(self.Policy, "Reseted", function()
		self:UpdateTables();
	end);
	
	self:OnPropertyChanged("AutoRefresh", function()
		self:UpdateTables();
	end);
end

-- public
function SpamViewModel:SetAutoRefresh(enabled)
	self:SetProperty("AutoRefresh", enabled);
end

-- private
function SpamViewModel:UpdateTables()
	if self.AutoRefresh == false then
		return;
	end

	self:UpdateNoSpamWordsTable();
	self:UpdateIsSpamWordsTable();
end

-- private
function SpamViewModel:UpdateNoSpamWordsTable()
	local temp = {};

	for k, v in pairs(self.Policy._noSpamWords) do
		table.insert(temp, k .. " " .. v);
	end

	table.sort(temp);
	self:SetProperty("NoSpamWordsTable", temp);
	self:SetProperty("NumNoSpamWords", self.Policy._numNoSpamWords);
	self:SetProperty("NumNoSpamWordEntries", #temp);
end

-- private
function SpamViewModel:UpdateIsSpamWordsTable()
	local temp = {};

	for k, v in pairs(self.Policy._isSpamWords) do
		table.insert(temp, k .. " " .. v);
	end

	table.sort(temp);
	self:SetProperty("IsSpamWordsTable", temp);
	self:SetProperty("NumIsSpamWords", self.Policy._numIsSpamWords);
	self:SetProperty("NumIsSpamWordEntries", #temp);
end
